/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const co = require('co')
const apemanrequest = require('apemanrequest')
const apemansleep = require('apemansleep')
const apemanport = require('apemanport')
const apemanApp = require('apeman-app')
const assert = require('assert')

describe('create', () => {
  let server, baseUrl
  let request = apemanrequest.create()
  let sleep = apemansleep.create()
  before(() => co(function * () {
    let app = create({})
    assert.ok(app)
    let port = yield apemanport.find()
    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '': [
              app,
              require('apeman-app-route')({
                '/foo/bar': (ctx) => {
                  ctx.body = 'done!!'
                }
              })
            ]
          }
        }
      }
    })
    baseUrl = `http://localhost:${port}`
  }))

  after(() => co(function * () {
    yield sleep.sleep(10)
    yield server.close()
  }))

  it('Send a request', () => co(function * () {
    let { body, statusCode } = yield request({
      method: 'GET',
      url: `${baseUrl}/foo/bar`
    })
    assert.ok(body)
    assert.equal(statusCode, 200)
  }))
})

/* global describe, before, after, it */
